==> cms-db_v0.6.tar.gz: admin/locales/de/locale_backup-action.php <==
<?php
/*  cms-db  Copyright (C) 2007-2009 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

$locale['backup-action'] = array();

/* Start Generation */
$locale['backup-action']['title_backup-complete'] = 'Komplettes Backup';
$locale['backup-action']['title_backup-files'] = 'Datei-Backup';
$locale['backup-action']['title_backup-gb-tpl'] = 'Gästebuch- und Template-Backup';
$locale['backup-action']['title_backup-includes'] = 'Include-Backup';
$locale['backup-action']['title_backup-pages'] = 'Seiten-Backup';
$locale['backup-action']['desc_backup-ready'] = 'Das Backup wurde erstellt.';
$locale['backup-action']['link_backup-download'] = 'Herunterladen';
/* End Generation */

/* Start Unzip */
$locale['backup-action']['title_backup-unzip'] = 'Backup hochladen';
$locale['backup-action']['desc_select-file'] = 'Bitte eine Datei wählen:';
$locale['backup-action']['button_upload-install'] = 'Backup hochladen und installieren';
$locale['backup-action']['desc_overwritten-data'] = 'Hinweis: Bereits bestehende Seiten, Dateien, Includes, Gästebucheinträge und das Template werden beim Hochladen des Backups evtl. überschrieben.<br />Um Fehlfunktionen zu vermeiden wird empfohlen, alle Seiten vor dem Entpacken eines Seiten-Backups zu löschen.';
$locale['backup-action']['desc_install-alternative'] = 'Sie können Backups auch manuell hochladen. Laden Sie dazu Inhalt des Ordners cms-db_backup_* des ZIP-Archivs in den richtigen Ordner hoch:';
$locale['backup-action']['desc_type'] = 'Backup-Typ';
$locale['backup-action']['desc_unzip-ready'] = 'Das Backup wurde erfolgreich entpackt.';
$locale['backup-action']['desc_unknown-format'] = 'Das hochgeladene Archiv ist kein cms -db-Backup. Backups von älteren Versionen als 0.4 werden nicht unterstützt.';
$locale['backup-action']['desc_archive-corrupt'] = 'Das hochgeladene Archiv ist defekt.';
$locale['backup-action']['desc_copy-error'] = 'Datei konnte nicht kopiert werden.';
$locale['backup-action']['desc_unknown-suffix'] = 'Die Datei besitzt eine ungültige Endung. Sie muss mit ".zip" enden.';
$locale['backup-action']['desc_no-file'] = 'Es wurde keine Datei hochgeladen. Möglicherweise überschreitet die Größe der Datei die maximale POST-Größe von PHP.';
/* End Unzip */
?>

==> cms-db_v0.6.1.tar.gz: admin/locales/de/locale_backup-action.php <==
<?php
/*  cms-db  Copyright (C) 2007-2009 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

$locale['backup-action'] = array();

/* Start Generation */
$locale['backup-action']['title_backup-complete'] = 'Komplettes Backup';
$locale['backup-action']['title_backup-files'] = 'Datei-Backup';
$locale['backup-action']['title_backup-gb-tpl'] = 'Gästebuch- und Template-Backup';
$locale['backup-action']['title_backup-includes'] = 'Include-Backup';
$locale['backup-action']['title_backup-pages'] = 'Seiten-Backup';
$locale['backup-action']['desc_backup-ready'] = 'Das Backup wurde erstellt.';
$locale['backup-action']['link_backup-download'] = 'Herunterladen';
/* End Generation */

/* Start Unzip */
$locale['backup-action']['title_backup-unzip'] = 'Backup hochladen';
$locale['backup-action']['desc_select-file'] = 'Bitte eine Datei wählen:';
$locale['backup-action']['button_upload-install'] = 'Backup hochladen und installieren';
$locale['backup-action']['desc_overwritten-data'] = 'Hinweis: Bereits bestehende Seiten, Dateien, Includes, Gästebucheinträge und das Template werden gelöscht.';
$locale['backup-action']['desc_install-alternative'] = 'Sie können Backups auch manuell hochladen. Laden Sie dazu Inhalt des Ordners cms-db_backup_* des ZIP-Archivs in den richtigen Ordner hoch:';
$locale['backup-action']['desc_type'] = 'Backup-Typ';
$locale['backup-action']['desc_unzip-ready'] = 'Das Backup wurde erfolgreich entpackt.';
$locale['backup-action']['desc_unknown-format'] = 'Das hochgeladene Archiv ist kein cms -db-Backup. Backups von älteren Versionen als 0.4 werden nicht unterstützt.';
$locale['backup-action']['desc_archive-corrupt'] = 'Das hochgeladene Archiv ist defekt.';
$locale['backup-action']['desc_copy-error'] = 'Datei konnte nicht kopiert werden.';
$locale['backup-action']['desc_unknown-suffix'] = 'Die Datei besitzt eine ungültige Endung. Sie muss mit ".zip" enden.';
$locale['backup-action']['desc_no-file'] = 'Es wurde keine Datei hochgeladen. Möglicherweise überschreitet die Größe der Datei die maximale POST-Größe von PHP.';
/* End Unzip */
?>
